@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.07';
+our $VERSION = '1.071'; # must be numeric, i.e. not 1.07.1
 $VERSION = eval $VERSION;
 
 use strict;
@@ -347,7 +347,7 @@ sub me {
 sub list_subreddits {
     	my ($self, %param) = @_;
 
-	my $type = $param{view} || croak "expected view";
+	my $type = $param{view} || SUBREDDITS_HOME;
     	my $query  = {};
         $query->{before} = $param{before} if $param{before};
         $query->{after}  = $param{after}  if $param{after};
@@ -367,12 +367,36 @@ sub list_subreddits {
     ];
 }
 
-sub contrib_subreddits { return $_[0]->list_subreddits(view=>SUBREDDITS_CONTRIB) }
-sub home_subreddits    { return $_[0]->list_subreddits(view=>SUBREDDITS_HOME)    }
-sub mod_subreddits     { return $_[0]->list_subreddits(view=>SUBREDDITS_MOD)     }
-sub my_subreddits      { return $_[0]->list_subreddits(view=>SUBREDDITS_MINE)    }
-sub new_subreddits     { return $_[0]->list_subreddits(view=>SUBREDDITS_NEW)     }
-sub popular_subreddits { return $_[0]->list_subreddits(view=>SUBREDDITS_POPULAR) }
+sub contrib_subreddits { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_CONTRIB;	
+	return $_[0]->list_subreddits(%param);
+}
+sub home_subreddits    { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_HOME;
+	return $_[0]->list_subreddits(%param);
+}
+sub mod_subreddits     { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_MOD;
+	return $_[0]->list_subreddits(%param);
+}
+sub my_subreddits      { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_MINE;
+	return $_[0]->list_subreddits(%param);
+}
+sub new_subreddits     { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_NEW;
+	return $_[0]->list_subreddits(%param);
+}
+sub popular_subreddits { 
+	my ($self, %param) = @_;
+	$param{view} = SUBREDDITS_POPULAR;
+	return $_[0]->list_subreddits(%param);
+}
 
 #===============================================================================
 # Inbox and messages
@@ -526,13 +550,8 @@ sub get_subreddit_comments {
 	my $view 	= $param{view} 		|| VIEW_DEFAULT;
 
 	my $query = {};
-        #$query->{before} = $before if defined $before;
-        #$query->{after}  = $after  if defined $after;
         $query->{before} = $param{before} if $param{before};
         $query->{after}  = $param{after}  if $param{after};
-	# if limit exists but is false (for "no limit"), get as many as possible
-	# this will probably be 100 but ask for a ridiculous amount anyway
-	# if we don't provide a limit, Reddit will give us 25
 	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
 	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
 
@@ -1041,6 +1060,17 @@ with an api_type of "json". After the request is complete, parses the
 JSON result and throws and error if one is specified in the result
 contents. Otherwise, returns the json data portion of the result.
 
+=item    authenticate
+
+=item   authorize
+
+=item    get_permalink
+
+=item    get_token
+
+=item    is_logged_in
+
+=item    send_message
 
 =item api_json_request
 
